@@ -1,6 +1,6 @@
 from abc import ABC, abstractmethod
 
-from ..models import VerificationResult
+from .models import VerificationResult
 
 
 class SignatureVerifierABC(ABC):
